{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "qiime2: Creates a directory populated with specifically named files as required by qiime2 EMPPairedEndSequences",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "label": "barcode read associated with each sequence",
                    "id": "#EMPPairedEndSequences-directory.cwl/barcodes"
                },
                {
                    "type": "string",
                    "label": "Name of the resulting directory",
                    "default": "emp-single-end-sequences",
                    "id": "#EMPPairedEndSequences-directory.cwl/directory_name"
                },
                {
                    "type": "File",
                    "label": "forward sequence reads",
                    "id": "#EMPPairedEndSequences-directory.cwl/forward_sequences"
                },
                {
                    "type": "File",
                    "label": "reverse sequence reads",
                    "id": "#EMPPairedEndSequences-directory.cwl/reverse_sequences"
                }
            ],
            "arguments": [
                "mkdir",
                "$(inputs.directory_name)",
                "&&",
                "cp",
                "$(inputs.forward_sequences.path)",
                "$(inputs.directory_name)/forward.fastq.gz",
                "&&",
                "cp",
                "$(inputs.reverse_sequences.path)",
                "$(inputs.directory_name)/reverse.fastq.gz",
                "&&",
                "cp",
                "$(inputs.barcodes.path)",
                "$(inputs.directory_name)/barcodes.fastq.gz"
            ],
            "id": "#EMPPairedEndSequences-directory.cwl",
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.directory_name)"
                    },
                    "id": "#EMPPairedEndSequences-directory.cwl/dir"
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "label": "qiime2 importing data",
            "doc": "Obtaining and importing data from https://docs.qiime2.org/2018.4/tutorials/moving-pictures/",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/barcodes"
                },
                {
                    "type": "File",
                    "id": "#main/forward_sequences"
                },
                {
                    "type": "File",
                    "id": "#main/reverse_sequences"
                },
                {
                    "type": "string",
                    "default": "emp-paired-end-sequences.qza",
                    "id": "#main/sequences_artifact_filename"
                },
                {
                    "type": "string",
                    "default": "EMPPairedEndSequences",
                    "id": "#main/sequences_artifact_type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/make_sequences_artifact/sequences_artifact",
                    "id": "#main/sequences_artifact"
                }
            ],
            "steps": [
                {
                    "run": "#EMPPairedEndSequences-directory.cwl",
                    "in": [
                        {
                            "source": "#main/barcodes",
                            "id": "#main/make_import_directory/barcodes"
                        },
                        {
                            "source": "#main/forward_sequences",
                            "id": "#main/make_import_directory/forward_sequences"
                        },
                        {
                            "source": "#main/reverse_sequences",
                            "id": "#main/make_import_directory/reverse_sequences"
                        }
                    ],
                    "out": [
                        "#main/make_import_directory/dir"
                    ],
                    "id": "#main/make_import_directory"
                },
                {
                    "run": "#tools-import.cwl",
                    "in": [
                        {
                            "source": "#main/make_import_directory/dir",
                            "id": "#main/make_sequences_artifact/input_path"
                        },
                        {
                            "source": "#main/sequences_artifact_filename",
                            "id": "#main/make_sequences_artifact/output_filename"
                        },
                        {
                            "source": "#main/sequences_artifact_type",
                            "id": "#main/make_sequences_artifact/type"
                        }
                    ],
                    "out": [
                        "#main/make_sequences_artifact/sequences_artifact"
                    ],
                    "id": "#main/make_sequences_artifact"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "qiime2: Import data to create a new QIIME 2 Artifact",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "qiime2/core:2018.4",
                    "id": "#qiime2-docker-hint.yml",
                    "name": "#qiime2-docker-hint.yml"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "label": "path to file or directory that should be imported",
                    "inputBinding": {
                        "prefix": "--input-path"
                    },
                    "id": "#tools-import.cwl/input_path"
                },
                {
                    "type": "string",
                    "label": "filename to use for output file (qza format)",
                    "inputBinding": {
                        "prefix": "--output-path"
                    },
                    "id": "#tools-import.cwl/output_filename"
                },
                {
                    "type": "string",
                    "label": "semantic type of the artifact that will be created upon importing",
                    "inputBinding": {
                        "prefix": "--type"
                    },
                    "id": "#tools-import.cwl/type"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#tools-import.cwl/sequences_artifact"
                }
            ],
            "baseCommand": [
                "qiime",
                "tools",
                "import"
            ],
            "id": "#tools-import.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
